@@ -1,6 +1,6 @@
 from cc_db.session_handler import SessionHandler
 from sqlalchemy import Column
-from sqlalchemy import String, Integer*
+from sqlalchemy import String, Integer
 from cc_db.engines import *
 
 
@@ -19,3 +19,4 @@ class Company(Base,SessionHandler):
   
   
 # C:/Users/p.dietrich/Documents/CargoCast/cc-forecast/cc.forecast/virtualenv/cc_db
+# C:/Users/p.dietrich/Documents/CargoCast/cc-forecast/cc.forecast/virtualenv/.venv/Scripts/activate
