@@ -35,7 +35,7 @@ class SessionHandler():
     params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False and k not in keys}
     instance = session.query(obj.__class__).filter_by(**key_values)
     if instance:
-      instance.update(**params)
+      instance.update(params)
     else:
       session.add(obj)
     return session
